"""
    This file is part of Accountant.

    Accountant is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Accountant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with Accountant.  If not, see <http://www.gnu.org/licenses/>.
"""
from copy import deepcopy

from flask.ext.restful import fields

# Account model.
account_model = {
    'id': fields.Integer(default=None),
    'name': fields.String,
    'authorized_overdraft': fields.Float,
}

# Account status model.
solds_model = {
    'current': fields.Float,
    'pointed': fields.Float,
    'future': fields.Float,
}

# Account balance model.
balance_model = {
    'expenses': fields.Float,
    'revenues': fields.Float,
    'balance': fields.Float,
}

# Category with expenses and revenues.
category_model = {
    'category': fields.String,
    'expenses': fields.Float,
    'revenues': fields.Float
}

# OHLC model.
ohlc_model = {
    'operation_date': fields.DateTime(dt_format='iso8601'),
    'open': fields.Float,
    'high': fields.Float,
    'low': fields.Float,
    'close': fields.Float
}

# Operation with sold model.
operation_model = {
    'id': fields.Integer(default=None),
    'operation_date': fields.DateTime(dt_format='iso8601'),
    'label': fields.String,
    'value': fields.Float,
    'pointed': fields.Boolean,
    'category': fields.String,
    'account_id': fields.Integer,
    'scheduled_operation_id': fields.Integer(default=None),
    'confirmed': fields.Boolean,
    'canceled': fields.Boolean,
}

operation_with_sold_model = deepcopy(operation_model)
operation_with_sold_model['sold'] = fields.Float

# Scheduled operation model.
scheduled_operation_model = {
    'id': fields.Integer,
    'start_date': fields.DateTime(dt_format='iso8601'),
    'stop_date': fields.DateTime(dt_format='iso8601'),
    'day': fields.Integer,
    'frequency': fields.Integer,
    'label': fields.String,
    'value': fields.Float,
    'category': fields.String,
    'account_id': fields.Integer,
}

# Token with expiration time and type.
token_model = {
    'token': fields.String,
    'expiration': fields.DateTime(dt_format='iso8601'),
    'token_type': fields.String
}

# User model.
user_model = {
    'id': fields.Integer(default=None),
    'email': fields.String,
    'active': fields.Boolean
}
