"""
    This file is part of Accountant.

    Accountant is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Accountant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with Accountant.  If not, see <http://www.gnu.org/licenses/>.
"""
from flask.ext.restful import Resource, fields, marshal_with_field

from accountant import db

from .. import api

from ..models.operations import Operation

from .models import operation_model, operation_with_sold_model
from .parsers import operation_parser, account_range_parser
from .users import requires_auth

from ..fields import Object


class OperationListResource(Resource):
    @requires_auth
    @marshal_with_field(fields.List(Object(operation_with_sold_model)))
    def get(self):
        data = account_range_parser.parse_args()

        return Operation.query(
            begin=data['begin'],
            end=data['end']
        ).filter(
            Operation.account_id == data['account_id']
        ).all(), 200

    @requires_auth
    @marshal_with_field(Object(operation_model))
    def post(self):
        data = operation_parser.parse_args()

        operation = Operation(**data)

        db.session.add(operation)

        return operation, 201


class OperationResource(Resource):
    @requires_auth
    @marshal_with_field(Object(operation_model))
    def get(self, id):
        """
        Get operation.
        """
        operation = db.session.query(Operation).get(id)

        if not operation:
            return None, 404

        return operation, 200

    @requires_auth
    @marshal_with_field(Object(operation_model))
    def post(self, id):
        data = operation_parser.parse_args()

        assert (id not in data or data.id is None
                or data.id == id)

        operation = db.session.query(Operation).get(id)

        if not operation:
            return None, 404

        # SQLAlchemy objects ignore __dict__.update() with merge.
        for k, v in data.items():
            setattr(operation, k, v)

        db.session.merge(operation)

        return operation, 200

    @requires_auth
    @marshal_with_field(Object(operation_model))
    def delete(self, id):
        operation = db.session.query(Operation).get(id)

        if not operation:
            return None, 404

        db.session.delete(operation)

        return None, 204


api.add_resource(OperationListResource, "/operation")
api.add_resource(OperationResource, "/operation/<int:id>")
