"""
    This file is part of Accountant.

    Accountant is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Accountant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with Accountant.  If not, see <http://www.gnu.org/licenses/>.
"""
from copy import deepcopy
import dateutil.parser

from flask.ext.restful import reqparse

# Parser for a date range.
range_parser = reqparse.RequestParser()
range_parser.add_argument(
    'begin',
    type=lambda a: dateutil.parser.parse(a) if a else None
)
range_parser.add_argument(
    'end',
    type=lambda a: dateutil.parser.parse(a) if a else None
)

# Parser for an account id.
account_id_parser = reqparse.RequestParser()
account_id_parser.add_argument('account_id', type=int)

# Parser for a date range and an account id.
account_range_parser = range_parser.copy()
account_range_parser.add_argument(
    deepcopy(account_id_parser.args[0])
)

# Parser for an account.
account_parser = reqparse.RequestParser()
account_parser.add_argument('name', type=str, required=True)
account_parser.add_argument('authorized_overdraft', type=float, required=True)

# Parser for an operation.
operation_parser = reqparse.RequestParser()
# Must use lambda because the parser passes other parameters badly interpreted
# by dateutil.parser.parse
operation_parser.add_argument(
    'operation_date', type=lambda a: dateutil.parser.parse(a))
operation_parser.add_argument('label', type=str)
operation_parser.add_argument('value', type=float)
operation_parser.add_argument('pointed', type=bool)
operation_parser.add_argument('category', type=str)
operation_parser.add_argument('account_id', type=int)
operation_parser.add_argument('scheduled_operation_id', type=int)
operation_parser.add_argument('confirmed', type=bool)
operation_parser.add_argument('canceled', type=bool)

# Parser for a scheduled operation.
scheduled_operation_parser = reqparse.RequestParser()
scheduled_operation_parser.add_argument(
    'start_date', type=lambda a: dateutil.parser.parse(a))
scheduled_operation_parser.add_argument(
    'stop_date', type=lambda a: dateutil.parser.parse(a))
scheduled_operation_parser.add_argument('day', type=int)
scheduled_operation_parser.add_argument('frequency', type=int)
scheduled_operation_parser.add_argument('label', type=str)
scheduled_operation_parser.add_argument('value', type=float)
scheduled_operation_parser.add_argument('category', type=str)
scheduled_operation_parser.add_argument('account_id', type=int)

# Parser for a login.
login_parser = reqparse.RequestParser()
login_parser.add_argument('email', type=str, required=True)
login_parser.add_argument('password', type=str, required=True)
